@@ -5,14 +5,29 @@ from __future__ import (print_function, division, unicode_literals,
 import os.path as op
 import nibabel as nb
 import numpy as np
+from distutils.version import LooseVersion
 
 from ...utils import NUMPY_MMAP
 
 from ... import logging
 from ..base import (traits, TraitedSpec, File, isdefined)
-from .base import DipyBaseInterface
+from .base import (HAVE_DIPY, dipy_version, dipy_to_nipype_interface,
+                   get_dipy_workflows, DipyBaseInterface)
 
-IFLOGGER = logging.getLogger('interface')
+IFLOGGER = logging.getLogger('nipype.interface')
+
+if HAVE_DIPY and LooseVersion(dipy_version()) >= LooseVersion('0.15'):
+    from dipy.workflows import denoise, mask
+
+    l_wkflw = get_dipy_workflows(denoise) + get_dipy_workflows(mask)
+    for name, obj in l_wkflw:
+        new_name = name.replace('Flow', '')
+        globals()[new_name] = dipy_to_nipype_interface(new_name, obj)
+    del l_wkflw
+
+else:
+    IFLOGGER.info("We advise you to upgrade DIPY version. This upgrade will"
+                  " open access to more function")
 
 
 class ResampleInputSpec(TraitedSpec):
@@ -106,8 +121,8 @@ class DenoiseInputSpec(TraitedSpec):
         desc=('mask in which the standard deviation of noise '
               'will be computed'),
         exists=True)
-    patch_radius = traits.Int(1, desc='patch radius')
-    block_radius = traits.Int(5, desc='block_radius')
+    patch_radius = traits.Int(1, usedefault=True, desc='patch radius')
+    block_radius = traits.Int(5, usedefault=True, desc='block_radius')
     snr = traits.Float(desc='manually set an SNR')
 
 
@@ -123,7 +138,7 @@ class Denoise(DipyBaseInterface):
 
     .. [Coupe2008] Coupe P et al., `An Optimized Blockwise Non Local Means
       Denoising Filter for 3D Magnetic Resonance Images
-      <http://dx.doi.org/10.1109%2FTMI.2007.906087>`_,
+      <https://doi.org/10.1109%2FTMI.2007.906087>`_,
       IEEE Transactions on Medical Imaging, 27(4):425-441, 2008.
 
 
