@@ -4,8 +4,9 @@ from __future__ import absolute_import
 # -*- coding: utf-8 -*-
 
 from .utils import (Mesh2PVE, Generate5tt, BrainMask, TensorMetrics,
-                    ComputeTDI, TCK2VTK)
-from .preprocess import ResponseSD, ACTPrepareFSL, ReplaceFSwithFIRST
+                    ComputeTDI, TCK2VTK, MRMath, MRConvert, DWIExtract)
+from .preprocess import (ResponseSD, ACTPrepareFSL, ReplaceFSwithFIRST,
+                         DWIDenoise, MRDeGibbs, DWIBiasCorrect)
 from .tracking import Tractography
 from .reconst import FitTensor, EstimateFOD
-from .connectivity import LabelConfig, BuildConnectome
+from .connectivity import LabelConfig, LabelConvert, BuildConnectome
