@@ -832,6 +832,27 @@ def emptydirs(path, noexist_ok=False):
     makedirs(path)
 
 
+def silentrm(filename):
+    """
+    Equivalent to ``rm -f``, returns ``False`` if the file did not
+    exist.
+
+    Parameters
+    ----------
+
+    filename : str
+        file to be deleted
+
+    """
+    try:
+        os.remove(filename)
+    except OSError as e:
+        if e.errno != errno.ENOENT:
+            raise
+        return False
+    return True
+
+
 def which(cmd, env=None, pathext=None):
     """
     Return the path to an executable which would be run if the given
@@ -880,24 +901,29 @@ def get_dependencies(name, environ):
     Uses otool on darwin, ldd on linux. Currently doesn't support windows.
 
     """
+    command = None
     if sys.platform == 'darwin':
-        proc = sp.Popen(
-            'otool -L `which %s`' % name,
-            stdout=sp.PIPE,
-            stderr=sp.PIPE,
-            shell=True,
-            env=environ)
+        command = 'otool -L `which %s`' % name
     elif 'linux' in sys.platform:
-        proc = sp.Popen(
-            'ldd `which %s`' % name,
-            stdout=sp.PIPE,
-            stderr=sp.PIPE,
-            shell=True,
-            env=environ)
+        command = 'ldd `which %s`' % name
     else:
         return 'Platform %s not supported' % sys.platform
-    o, e = proc.communicate()
-    return o.rstrip()
+
+    deps = None
+    try:
+        proc = sp.Popen(
+            command,
+            stdout=sp.PIPE,
+            stderr=sp.PIPE,
+            shell=True,
+            env=environ)
+        o, e = proc.communicate()
+        deps = o.rstrip()
+    except Exception as ex:
+        deps = '"%s" failed' % command
+        fmlogger.warning('Could not get dependencies of %s. Error:\n%s',
+                         name, ex.message)
+    return deps
 
 
 def canonicalize_env(env):
